Index: /issm/trunk-jpl/src/c/classes/Cfdragcoeffabsgrad.cpp
===================================================================
--- /issm/trunk-jpl/src/c/classes/Cfdragcoeffabsgrad.cpp	(revision 27684)
+++ /issm/trunk-jpl/src/c/classes/Cfdragcoeffabsgrad.cpp	(revision 27685)
@@ -137,5 +137,5 @@
 	Input        *drag_input   = NULL;
 
 	/* get the friction law: if 2-Weertman, 11-Schoof or 14-RegularizedCoulomb, which has a different names of C */
 	element->FindParam(&frictionlaw, FrictionLawEnum);
 	switch(frictionlaw) {
@@ -143,4 +143,5 @@
 		case 11:
 		case 14:
+		case 15:
 			drag_input = basalelement->GetInput(FrictionCEnum); _assert_(drag_input);
 			break;
@@ -137,5 +137,5 @@
 	Input        *drag_input   = NULL;
 
-	/* get the friction law: if 2-Weertman, 11-Schoof or 14-RegularizedCoulomb, which has a different names of C */
+	/* get the friction law: if 2-Weertman, 11-Schoof, 14-RegularizedCoulomb 15-RegularizedCoulomb2, which has a different names of C */
 	element->FindParam(&frictionlaw, FrictionLawEnum);
 	switch(frictionlaw) {
